@@ -3,7 +3,10 @@ use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = '0.003_002'; # TRIAL VERSION
+our $VERSION = '0.004_001'; # TRIAL VERSION
+
+use base 'Exporter';
+our @EXPORT_OK = qw/ Load LoadFile Dump DumpFile /;
 
 sub new {
     my ($class, %args) = @_;
@@ -14,11 +17,26 @@ sub new {
 
 sub loader { return $_[0]->{loader} }
 
+# legagy interface
 sub Load {
     require YAML::PP::Loader;
-    my ($self, $yaml) = @_;
-    $self->{loader} = YAML::PP::Loader->new;
-    return $self->loader->load($yaml);
+    my ($yaml) = @_;
+    my $loader = YAML::PP::Loader->new;
+    return $loader->load_string($yaml);
+}
+
+sub LoadFile {
+    require YAML::PP::Loader;
+    my ($file) = @_;
+    my $loader = YAML::PP::Loader->new;
+    return $loader->load_file($file);
+}
+
+sub Dump {
+    require YAML::PP::Dumper;
+    my (@data) = @_;
+    my $dumper = YAML::PP::Dumper->new;
+    return $dumper->dump_string(@data);
 }
 
 1;
@@ -40,15 +58,19 @@ WARNING: This is highly experimental.
 Here are a few examples of what you can do right now:
 
     my $yppl = YAML::PP::Loader->new;
-    my @documents = $yppl->load($yaml);
+    my @documents = $yppl->load_string($yaml);
+
+    # load file
+    my $yppl = YAML::PP::Loader->new;
+    my @documents = $yppl->load_file($filename);
 
     # The loader offers JSON::PP, boolean.pm or pureperl 1/0 (default)
     # for booleans
     my $yppl = YAML::PP::Loader->new(boolean => 'JSON::PP');
-    my ($data1, $data2) = $yppl->load($yaml);
+    my ($data1, $data2) = $yppl->load_string($yaml);
 
     my $yppd = YAML::PP::Dumper->new();
-    my $yaml = $yppd->dump($data1, $data2);
+    my $yaml = $yppd->dump_string($data1, $data2);
 
 Some utility scripts:
 
@@ -166,7 +188,7 @@ own boolean handling.
 =item Numbers
 
 Numbers are created as real numbers instead of strings, so that they are
-dumped correctly by modules like L<JSON::XS>, for example.
+dumped correctly by modules like L<JSON::PP> or L<JSON::XS>, for example.
 
 See L<"NUMBERS"> for an example.
 
@@ -186,9 +208,9 @@ I would like to add a possibility to specify a method for stringification.
 Example:
 
     use YAML::PP::Loader;
-    use JSON::XS;
+    use JSON::PP;
     my $yppl = YAML::PP::Loader->new;
-    my $coder = JSON::XS->new->ascii->pretty->allow_nonref->canonical;
+    my $coder = JSON::PP->new->ascii->pretty->allow_nonref->canonical;
     my $yaml = <<'EOM';
     complex:
         ?
@@ -198,7 +220,7 @@ Example:
             : 23
         : 42
     EOM
-    my $data = $yppl->load($yaml);
+    my $data = $yppl->load_string($yaml);
     say $coder->encode($data);
     __END__
     {
@@ -247,9 +269,9 @@ The layout is like libyaml output:
 
 =head1 NUMBERS
 
-Compare the output of the following YAML Loaders and JSON::XS dump:
+Compare the output of the following YAML Loaders and JSON::PP dump:
 
-    use JSON::XS;
+    use JSON::PP;
     use Devel::Peek;
 
     use YAML::XS ();
@@ -266,7 +288,7 @@ Compare the output of the following YAML Loaders and JSON::XS dump:
     my $d2 = YAML::Load($yaml);
     my $d3 = YAML::Syck::Load($yaml);
     my $d4 = YAML::Tiny->read_string($yaml)->[0];
-    my $d5 = YAML::PP::Loader->new->load($yaml);
+    my $d5 = YAML::PP::Loader->new->load_string($yaml);
 
     Dump $d1->{foo};
     Dump $d2->{foo};
