@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Exception;
 
-our $VERSION = '0.003_002'; # TRIAL VERSION
+our $VERSION = '0.004_001'; # TRIAL VERSION
 
 use overload '""' => \&to_string;
 
@@ -25,13 +25,14 @@ sub to_string {
     for my $token (@$next) {
         $yaml .= $token->{value};
     }
-    my $remaining_yaml = ${ $self->{yaml} };
+    my $remaining_yaml = $self->{yaml}->[0] // '';
     $yaml .= $remaining_yaml;
     $yaml =~ s/[\r\n].*//s;
     {
+        local $@; # avoid bug in old Data::Dumper
+        require Data::Dumper;
         local $Data::Dumper::Useqq = 1;
         local $Data::Dumper::Terse = 1;
-        require Data::Dumper;
         $yaml = Data::Dumper->Dump([$yaml], ['yaml']);
         chomp $yaml;
     }
